@@ -160,6 +160,10 @@ class AptBundleInstallerExtension(BundleInstallerExtensionPoint):
         # Workaround for pip-requirements not installing python-pip
         self.add_to_install_list('python3-pip')
 
+        # Currently not available in Focal
+        if get_ubuntu_distribution_version() != 'focal':
+            self.add_to_install_list('python-pip')
+
     def _separate_version_information(self, package_name):
         if '=' not in package_name:
             return package_name, ''
